@@ -12,7 +12,7 @@ use Email::MIME;
 use Email::MIME::CreateHTML;
 use Email::Sender::Simple 'sendmail';
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 sub new {
     my $self = shift;
@@ -119,7 +119,7 @@ sub send {
         }
 
         # send the email with Email::Sender::Simple
-        sendmail( $email_mime, $mail->{transport} );
+        sendmail( $email_mime, { transport => $mail->{transport} } );
 
         $_;
     } ( ref $_[0] eq 'HASH' ) ? ( map { $self->new(%$_) } @_ ) : $self->new(@_);
@@ -142,7 +142,7 @@ Email::Mailer - Multi-purpose emailer for HTML, auto-text, attachments, and temp
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Email-Mailer.svg)](https://travis-ci.org/gryphonshafer/Email-Mailer)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Email-Mailer/badge.png)](https://coveralls.io/r/gryphonshafer/Email-Mailer)
